---
name: Bug report
about: Report a problem with the myPyllant library
title: ''
labels: ''
assignees: ''

---

### Before submitting a new issue

- [ ] I'm using the latest version of myPyllant
- [ ] I've checked [known issues](https://signalkraft.com/mypyllant-component/#known-issues)
- [ ] I'm sure this problem is about the myPyllant library. For issues with the home assistant component, [open an issue here](https://github.com/signalkraft/mypyllant-component/issues/new/choose)

### Problem description

Please describe what you were trying to do, what happened, and what you expected to happen.
